@@ -10,7 +10,7 @@ our %Remote = (
     extract => sub {
         return    # support for Unicode female/male symbols
             map { tr/-'. /_/s; s/\xe2\x99\x80/female/; s/\xe2\x99\x82/male/; $_ }
-            $_[0] =~ m!<td>\d+</td>\s*<td><a href="/wiki/[^"]+" title="[^"]+">([^<]+)</a></td>!gm;
+            $_[0] =~ m!<td>(?:\d+|&#160;\?\?\?)</td>\s*<td><a href="/wiki/[^"]+" title="[^"]+">([^<]+)</a></td>!gm;
     },
 );
 
@@ -23,8 +23,7 @@ Acme::MetaSyntactic::pokemon - The Pokmon theme
 =head1 DESCRIPTION
 
 List of all Pokmon characters that are officially known to exist in the
-franchise, by national Pokdex number. The English names are used in this
-module.
+franchise The English names are used in this module.
 
 This list is based on the following wikipedia article:
 L<http://en.wikipedia.org/wiki/List_of_Pok%C3%A9mon_by_National_Pok%C3%A9dex_number>.
@@ -37,9 +36,11 @@ Introduced in version 0.56, published on January 9, 2006.
 
 Updated in version 0.57, published on January 16, 2006.
 
+Updated in version 0.59, published on January 30, 2006.
+
 =head1 SEE ALSO
 
-L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>,
+L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.
 
 =cut
 
@@ -90,4 +91,4 @@ Armaldo Feebas Milotic Castform Kecleon Shuppet Banette Duskull Dusclops
 Tropius Chimecho Absol Wynaut Snorunt Glalie Spheal Sealeo Walrein
 Clamperl Huntail Gorebyss Relicanth Luvdisc Bagon Shelgon Salamence
 Beldum Metang Metagross Regirock Regice Registeel Latias Latios Kyogre
-Groudon Rayquaza Jirachi Deoxys Munchlax
+Groudon Rayquaza Jirachi Deoxys Munchlax Bonsly Lucario
